utils

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ClearAfterCursor

func ClearAfterCursor()

func ClearScreen

func ClearScreen()

func IsValidUUID

func IsValidUUID(s string) bool

IsValidUUID returns true if s is a valid UUID otherwise returns false

func RestoreCursor

func RestoreCursor()

func SaveCursor

func SaveCursor()

func SplitAtCommas

func SplitAtCommas(s string) []string

splitAtCommas delimits a string by commas and removes duplicate values

NOTE: order is not maintained

func SplitFieldsAndCommas

func SplitFieldsAndCommas(s string) []string

Types

This section is empty.

Jump to