Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClearAfterCursor ¶
func ClearAfterCursor()
func ClearScreen ¶
func ClearScreen()
func IsValidUUID ¶
IsValidUUID returns true if s is a valid UUID otherwise returns false
func RestoreCursor ¶
func RestoreCursor()
func SaveCursor ¶
func SaveCursor()
func SplitAtCommas ¶
splitAtCommas delimits a string by commas and removes duplicate values
NOTE: order is not maintained
func SplitFieldsAndCommas ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.